"""
Plugin used to connect the tool to Github.

Will offer the user to open the url: https://git.sourceai.io/settings/tokens
to create a new token.

The users must give all the permission except:

- admin:gpg_key

"""

import click

from gamma.services.github import GitHubService


@click.command()
@click.pass_obj
def cli(telemetry):
    """ allowing you to connect with Github """

    if telemetry is not None:
        telemetry.track_event("login cmd")

    git = GitHubService()
    token = git.get_token()
    client = git.get_github_client(token)
    try:
        username = client.get_user().login
        print("you are succesfully logued under the username: " + username)
        if telemetry is not None:
            telemetry.track_event("github login OK")
            telemetry.flush()
    except:
        git.delete_token_file()
        print("invalid or expired token, please try again to use the login command")
        if telemetry is not None:
            telemetry.track_event("github login not OK")
            telemetry.flush()
