"""
Plugin used to create new resources:

- project using template and directly pushed to github if the user is OK
- trello board
- Virtual Machine
- ...

you can for example use:

`gamma new project --path ~/home/projects/`

to create a new project in the current directory.

`gamma new project --path ~/home/projects/`

to create a new project in the `~/home/projects/` directory.

a new directory will be create with the name of the project (asked during the
generation)


`gamma new trello`

to open the trello login page to be used with your entreprise account.

`gamma new vm`

to open a request to Gamma Platform to obtain a VM

"""

import webbrowser

import click

from gamma.services.project import ProjectService


@click.group()
@click.pass_obj
def cli(telemetry):
    """
    Allow you to create new project,...
    """

    if telemetry is not None:
        telemetry.track_event("git new cmd")
        telemetry.flush()


@cli.command()
@click.option("--path", default=None, help="path where to create the project")
def project(path: str):
    """
    Will create a new project from the template and propose you to push it
    on Github directly
    """
    new_project = ProjectService()
    new_project.new(path)


@cli.command()
def trello():
    """
    Open the webpage to connect to trello with your entreprise account,
    allowing you to create a new team/board
    """

    webbrowser.open("https://trello.com/login/sso", new=2, autoraise=True)


# pylint: disable=invalid-name
@cli.command()
def vm():
    """
    Open the webpage to connect to trello with your entreprise account,
    allowing you to create a new team/board
    """

    webbrowser.open(
        "https://jira.gamma.bcg.com/servicedesk/customer/portal/1/create/21",
        new=2,
        autoraise=True,
    )
