"""
Github services used to connect and handle all the operations with the Github API
"""

import os
from pathlib import Path

from github import Github


class GitHubService(object):
    """ Github service """

    def create_token(self, path: str) -> str:
        """ prompt for the token then save it in a file """

        print(
            "please visit https://git.sourceai.io/settings/tokens and write your token:"
        )
        token = input("token: ").lower().strip()
        os.makedirs(os.path.dirname(path), exist_ok=True)
        with open(path, "w") as file:
            file.write(token)

        return token

    def get_token_path(self) -> str:
        """ Returns the path of the token on the disk """

        home = str(Path.home())
        token_path = os.path.join(home, ".gamma", "github_token")
        return token_path

    def read_token(self, path: str) -> str:
        """ read the token from the file """

        with open(path, "r") as file:
            return file.read()

    def get_token(self) -> str:
        """ get the token from the file or prompt for it"""

        token_path = self.get_token_path()
        token_file = Path(token_path)
        token = None
        if token_file.is_file():
            token = self.read_token(token_path)
        else:
            token = self.create_token(token_path)

        return token

    def delete_token_file(self):
        """ Deletes the token file """

        token_path = self.get_token_path()
        if os.path.exists(token_path):
            os.remove(token_path)

    def get_github_client(self, token=None) -> Github:
        """ Create a github client from the token """

        if token is None:
            token = self.get_token()

        return Github(base_url="https://git.sourceai.io/api/v3", login_or_token=token)
